@@ -1,7 +1,7 @@
 package Log::ger;
 
 our $DATE = '2017-07-11'; # DATE
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 #IFUNBUILT
 # # use strict;
@@ -402,6 +402,8 @@ sub init_target {
 
     {
         local $hook_args{routines} = \@routines;
+        local $hook_args{formatters} = \%formatters;
+        local $hook_args{layouter} = $layouter;
         run_hooks('before_install_routines', \%hook_args, 0,
                   $target, $target_arg);
     }
@@ -480,7 +482,7 @@ Log::ger - A lightweight, flexible logging framework
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
